@@ -13,18 +13,29 @@ class _caption2:
     FONT_HEIGHT = FONT_SIZE_RATIO * 100 * 6
 
     @classmethod
-    def renderimage(cls, image: str, text: str = 'text here', _font_size_ratio_mul: float = 1.0) -> Image.Image:
+    def renderimage(cls, image: str, text: str = 'text here', _font_size_ratio_mul: float = 1.0, _border: bool = False) -> Image.Image:
         if len(text) == 0:
             text = 'text here'
 
         text = format_text(cls.LINE_LENGTH, text)
 
-        with resources.open_binary('resources.fonts', 'impact.ttf') as fp:
-            _font_file = io.BytesIO(fp.read())
-
         im = Image.open(image)
         editable_im = ImageDraw.Draw(im)
 
+        if _border:
+            with resources.open_binary('resources.fonts', 'impact.ttf') as fp:
+                _font_file = io.BytesIO(fp.read())
+            FONT = ImageFont.truetype(_font_file, int(cls.FONT_SIZE_RATIO * _font_size_ratio_mul * im.width))
+            _, _, _w, _h = editable_im.textbbox((0, 0), text, font=FONT)
+
+            editable_im.text(((im.width - _w)/2 + 1, 0), text, font=FONT, fill='black')
+            editable_im.text(((im.width - _w)/2 - 1, 0), text, font=FONT, fill='black')
+            editable_im.text(((im.width - _w)/2, 1), text, font=FONT, fill='black')
+            editable_im.text(((im.width - _w)/2, -1), text, font=FONT, fill='black')
+
+        with resources.open_binary('resources.fonts', 'impact.ttf') as fp:
+            _font_file = io.BytesIO(fp.read())
+
         FONT = ImageFont.truetype(_font_file, int(cls.FONT_SIZE_RATIO * _font_size_ratio_mul * im.width))
         _, _, _w, _h = editable_im.textbbox((0, 0), text, font=FONT)
 
